@@ -2,10 +2,15 @@
 	compile-time configuration for mserver
 */
 
+/* #define if we are building on a BSD system */
+
+#undef BSD
+
 /* location of the runtime config file */
 
-#define CONFIG		"/etc/mserver.conf"
+#define CONFIG		"/usr/local/etc/mserver.conf"
 
 /* location of the spool dir for modem locks */
 
-#define LOCK_DIR	"/var/spool/uucp"
+#define LOCK_DIR	"/var/lock"
+
